/*---------------------------------------------------------------------\
|                          ____ _   __ __ ___                          |
|                         |__  / \ / / . \ . \                         |
|                           / / \ V /|  _/  _/                         |
|                          / /__ | | | | | |                           |
|                         /_____||_| |_| |_|                           |
|                                                                      |
\---------------------------------------------------------------------*/
/** \file	zypp/zypp_detail/ZYppReadOnlyHack.h
 *
*/

#ifndef ZYPP_ZYPP_DETAIL_ZYPPREADONLYHACK_H
#define ZYPP_ZYPP_DETAIL_ZYPPREADONLYHACK_H
#warning ZYPP_ZYPP_DETAIL_ZYPPREADONLYHACK_H

#include <zypp/APIConfig.h>

///////////////////////////////////////////////////////////////////
namespace zypp
{ /////////////////////////////////////////////////////////////////
  ///////////////////////////////////////////////////////////////////
  namespace zypp_readonly_hack
  { /////////////////////////////////////////////////////////////////

    extern void IWantIt() ZYPP_DEPRECATED;

    /////////////////////////////////////////////////////////////////
  } // namespace zypp_readonly_hack
  ///////////////////////////////////////////////////////////////////
  /////////////////////////////////////////////////////////////////
} // namespace zypp
///////////////////////////////////////////////////////////////////

#endif // ZYPP_ZYPP_DETAIL_ZYPPREADONLYHACK_H
